/// Параметры для автокомплитера
function auto_completer_options() {
  return {
    method: 'get',
    onHide: function(element, update) { update.style.display = 'none' },
    onShow: function(element, update) {
      if(!update.style.position || update.style.position=='absolute') {
        update.style.position = 'absolute';
        Position.clone(element, update, {
          setHeight: false,
          offsetTop: element.offsetHeight
        });
      }
      update.style.display = 'block';
      // В некоторых браузерах при нечетной ширине тень внизу перекрывается на 1px
      // сдвигами делаем ширину всегда четной
      update.style.width = (element.getWidth() >> 1 << 1) + 'px';
    }
  };
}

function initSearchHint() {
  var input = $('query');
  if (input.value == '' || input.value == input.title) {
    function init() {
      input.addClassName('hint');
      input.value = input.title;
    }
    init();
    Event.observe(input, 'focus', function() {
      if (input.value == input.title) {
        input.removeClassName('hint');
        input.value = '';
      }
    });
    Event.observe(input, 'blur', function() {
      if (input.value == '') {
        init();
      }
    });
  }
}

function initDisableSubmits() {
  function disable_on_submit(el) {
    var form = el.form;
    if (!form) return;

    function form_submit_handler(e) {
      el.disabled = true;
    }

    form.observe('submit', form_submit_handler);
  }

  // все submit, исключая с классом s-not-disabled
  $$('input[type="submit"]:not([class="s-not-disabled"])').each(disable_on_submit);
}

Event.observe(document, 'dom:loaded', function() {
  // Ставим фокус в элемен формы с классом focused
  var focused = $$('input.focused').first();
  if (focused) focused.focus();

  initDisableSubmits();
  initSearchHint();
  addButtonsShadow();
  replaceDates();
});


/// Paginator shortcuts
Event.observe(document, 'keydown', function(e) {
  if (e.ctrlKey) {
    var tagName = e.target.tagName.toLowerCase();
    if (tagName != 'input' && tagName != 'textarea') {
      switch (e.keyCode) {
        case Event.KEY_LEFT:
          var prev = $('prev_page');
          if (prev) window.location = prev.href;
          break;
        case Event.KEY_RIGHT:
          var next = $('next_page');
          if (next) window.location = next.href;
          break;
        case Event.KEY_UP:
          var query = $('query');
          if (query) {
            query.focus();
            query.select();
          }
          break;
      }
    }
  }
});

/// Tag list
function initTagList() {
  var input = $('tag_list');
  var range = new Range(input);
  var selectTagRegexp = /^[^\s,]+,? *$/;
  var selectWordRegexp = /^[^\s,]+$/;

  var options = auto_completer_options();
  options.minChars = 3;
  options.callback = function() {
    return "value=" + range.selectPattern(selectWordRegexp) + '&list=' + input.value;
  };

  options.updateElement = function(item) {
    range.selectPattern(selectTagRegexp, null, true);
    range.replace(item.innerHTML + ', ');
    range.setCaret(input.value.length);
  };

  var tags_auto_completer = new Ajax.Autocompleter('tag_list', 'tag_autocomplete', '/tag_autocompleter', options);
}

/// Добавляем тень к тексту кнопок
function addButtonsShadow() {
  var buttons = $('page').select('div.button a');
  buttons.each(function(el) {
    var html = '<i class="shadow">' + $(el).innerHTML + '</i>';
    new Insertion.After(el, html);
  });
}

/// Заменяем даты на слова "сегодня", "вчера"
function replaceDates() {
  if (!$('terms')) return;

  var tday = new Date();
  var yday = new Date(tday);
  yday.setDate(yday.getDate() - 1);

  function date_string(date) {
    return date.getDate() + '.' + (date.getMonth() + 1) + '.' + date.getFullYear();
  }

  $('terms').select('div.date').each(function(el) {
    var title = el.title;
    if (title == date_string(tday)) {
      el.innerHTML = 'сегодня';
    } else if (title == date_string(yday)) {
      el.innerHTML = 'вчера';
    }
  });
}

// Голосование за определение
function vote(id, choice) {
  var url = (choice) ? '/definition/rate_plus/' : '/definition/rate_minus/';
  url = url + id
  new Ajax.Request(url, {
    evalScript: true,
    method: 'get',
    onComplete: function() {
      new Effect.Highlight('vote_' + id);
    }
  });
}

// Показываем один блок и скрываем другой
function showAndHide(show, hide) {
  $(show).style.display = 'block';
  $(hide).style.display = 'none';
}

// Выбираем, какой из промо блоков, необходимо показать
function choose_promo() {
    if (navigator.userAgent.indexOf('Firefox/2') > -1 || navigator.userAgent.indexOf('Firefox/3') > -1 || navigator.userAgent.indexOf('MSIE 7') > -1) {
      showAndHide('promo_opensearch', 'promo_rss');
    } else {
      showAndHide('promo_rss', 'promo_opensearch');
    }
}